@@ -3,9 +3,9 @@ import cmath
 '''
 Please don't change the below mentioned values of {errors} and {name}
 without reading the whole code.It might result in code ambiguity.
-##version==0.0.7##
+##version==0.1.0##
 '''
-negative_error ="Sides can't be less than or equal to zero"
+negative_error ="Side lengths can't be less than or equal to zero"
 no_of_side_error="Number of sides can't be float"
 name="py_math_help"
 
@@ -18,11 +18,12 @@ class triangle:
         else:
             if not(a>0 and b>0 and c>0):
                 raise ValueError( negative_error)
-            if a+b>c and b+c>a and c+a>b:
-                s=(a+b+c)/2
-                ar=s*(s-a)*(s-b)*(s-c)
-                return sqrt(ar)
-        
+            if not (a+b>c and b+c>a and c+a>b):
+                raise ValueError("Invalid length of sides for triangle\n Voilating (side1)+(side2)>(side3) rule")
+            s=(a+b+c)/2
+            ar=s*(s-a)*(s-b)*(s-c)
+            return sqrt(ar)                
+
     def perimeter(a,b,c):
         if not(a>0 and b>0 and c>0):
             raise ValueError( negative_error)
@@ -34,7 +35,7 @@ class quadilateral:
 
     def area(self,a,b=None):
         if self.name=="square" and a>0 and b!=None:
-            raise ValueError("Square accepts only one argumnet")          
+            raise ValueError("Square accepts only one argumnet (side length)")          
         if self.name=="square" and a>0 and b==None:
             return a*a
         try:    
@@ -46,7 +47,7 @@ class quadilateral:
 
     def perimeter(self,a,b=None):
         if self.name=="square" and a>0 and b!=None:
-            raise ValueError("Square accepts only one argumnet")  
+            raise ValueError("Square accepts only one argumnet (side length)")  
         if self.name=="square" and a>0 and b==None:
             return 4*a               
         try:    
@@ -87,15 +88,19 @@ def table(a):
 
 class polygon:
   def area(side,len):
-    if not(side>2 and len>0):
-        raise ValueError("Argument error")
+    if not(side>2):
+        raise ValueError("Minimum number of sides required for a polygon is 3.")
+    if not(len >0):
+        raise ValueError(negative_error)
     if not (isinstance(side,int)):
         raise TypeError( no_of_side_error)
     return float('%.5f'%((side*len*len)/(4*tan(pi/side))))
 
   def perimeter(side,len):
-    if not(side>2 and len>0):
-        raise ValueError("Argument error")
+    if not(side>2):
+        raise ValueError("Minimum number of sides required for a polygon is 3.")
+    if not(len >0):
+        raise ValueError(negative_error)
     if not (isinstance(side,int)):
         raise TypeError( no_of_side_error)      
     return side*len
@@ -104,11 +109,13 @@ class circle:
     def area(r):
         if not(r>0):
             raise ValueError( negative_error)
+        return pi*r*r
 
-    def perimeter(r):
+    def circumference(r):
         if not(r>0):
             raise ValueError( negative_error)
-
+        return 2*pi*r
+    
 def query(arg,input_string): 
     count=0
     for i in input_string.split(" "):
@@ -145,6 +152,19 @@ def query2(lst,a):
             for i in lst:
                 print(l[i][6:]) 
 
+def query3(control,lst,a):
+        if (query("binary",a) and (control !="binary")):
+            print(l[lst[0]])
+        elif (query("decimal",a) and (control !="decimal")):
+            print(l[lst[1]])
+        elif query("octal",a) and control!="octal":
+            print(l[lst[2]])
+        elif query("hexadecimal",a) and control!="hexadecimal":
+            print(l[lst[3]])
+        else:
+            for i in lst:
+                print(l[i])
+
 class three_d1:
     def __init__(self,name) -> None:
         self.name=name
@@ -229,19 +249,6 @@ class cuboid:
 def slant_height(r,h):
     return (sqrt(r*r+h*h))
 
-def query3(control,lst,a):
-        if (query("binary",a) and (control !="binary")):
-            print(l[lst[0]])
-        elif (query("decimal",a) and (control !="decimal")):
-            print(l[lst[1]])
-        elif query("octal",a) and control!="octal":
-            print(l[lst[2]])
-        elif query("hexadecimal",a) and control!="hexadecimal":
-            print(l[lst[3]])
-        else:
-            for i in lst:
-                print(l[i])
-
 def factorial(x,y=None):
     if (x==0 or x==1) and y==None:
         return 1
@@ -680,7 +687,7 @@ l=['',
   f'27.   VOLUME OF cone \n Syntax -> {name}.cone.volume(<radius>,<height>)', 
   f'28.   SLANT HEIGHT OF cone \n Syntax -> {name}.slant_height(<radius>,<height>)', 
   f'29.   AREA OF circle \n Syntax -> {name}.circle.area(<radius>)',
-  f'30.   PERIMETER OF circle \n Syntax -> {name}.circle.perimeter(<radius>)', 
+  f'30.   CIRCUMFERENCE OF circle \n Syntax -> {name}.circle.circumference(<radius>)', 
   f'31.   AREA OF parallelogram \n Syntax -> {name}.parallelogram.area(<digonal_1>,<digonal_2>)',
   f'32.   PERIMETER OF parallelogram \n Syntax -> {name}.parallelogram.perimeter(<side_1>,<side_2>)', 
   f'33.   CONVERT BINARY TO DECIMAL \n Syntax -> {name}.converter.bin_to_dec(<binary_number>)',   
